# Shopify GraphQL Client

A Python client to interact with the Shopify GraphQL Admin API, inspired by Guzzle-based PHP clients.

## Installation

```bash
pip install py-shopify-graphql-client

## Examples

See [examples/basic_usage.py](examples/basic_usage.py) for a working example.

```bash
python examples/basic_usage.py
